'use strict';

var _expect = require('expect.js');

var _expect2 = _interopRequireDefault(_expect);

var _jss = require('jss');

var _index = require('./index');

var _index2 = _interopRequireDefault(_index);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var settings = {
  generateClassName: function generateClassName(str, rule) {
    return rule.name + '-id';
  }
};

describe('jss-global', function () {
  var jss = void 0;

  beforeEach(function () {
    jss = (0, _jss.create)(settings).use((0, _index2['default'])());
  });

  describe('@global root container', function () {
    var sheet = void 0;

    beforeEach(function () {
      sheet = jss.createStyleSheet({
        '@global': {
          a: { color: 'red' },
          body: { color: 'green' }
        }
      });
    });

    it('should add rules', function () {
      (0, _expect2['default'])(sheet.getRule('@global')).to.not.be(undefined);
      (0, _expect2['default'])(sheet.getRule('a')).to.be(undefined);
      (0, _expect2['default'])(sheet.getRule('body')).to.be(undefined);
    });

    it('should generate correct CSS', function () {
      (0, _expect2['default'])(sheet.toString()).to.be('a {\n' + '  color: red;\n' + '}\n' + 'body {\n' + '  color: green;\n' + '}');
    });
  });

  describe('@global root prefix', function () {
    var sheet = void 0;

    beforeEach(function () {
      sheet = jss.createStyleSheet({
        '@global body': {
          color: 'red'
        }
      });
    });

    it('should add rules', function () {
      (0, _expect2['default'])(sheet.getRule('body')).to.be(undefined);
    });

    it('should generate correct CSS', function () {
      (0, _expect2['default'])(sheet.toString()).to.be('body {\n' + '  color: red;\n' + '}');
    });
  });

  describe('@global container inside of a regular rule', function () {
    var sheet = void 0;

    beforeEach(function () {
      sheet = jss.createStyleSheet({
        button: {
          float: 'left',
          '@global': {
            span: { color: 'red' }
          }
        }
      });
    });

    it('should add rules', function () {
      (0, _expect2['default'])(sheet.getRule('button')).to.not.be(undefined);
      (0, _expect2['default'])(sheet.getRule('.button-id span')).to.not.be(undefined);
    });

    it('should generate correct CSS', function () {
      (0, _expect2['default'])(sheet.toString()).to.be('.button-id {\n' + '  float: left;\n' + '}\n' + '.button-id span {\n' + '  color: red;\n' + '}');
    });
  });

  describe('@global prefix inside of a regular rule', function () {
    var sheet = void 0;

    beforeEach(function () {
      sheet = jss.createStyleSheet({
        button: {
          float: 'left',
          '@global span': {
            color: 'red'
          }
        }
      });
    });

    it('should add rules', function () {
      (0, _expect2['default'])(sheet.getRule('button')).to.not.be(undefined);
      (0, _expect2['default'])(sheet.getRule('.button-id span')).to.not.be(undefined);
    });

    it('should generate correct CSS', function () {
      (0, _expect2['default'])(sheet.toString()).to.be('.button-id {\n' + '  float: left;\n' + '}\n' + '.button-id span {\n' + '  color: red;\n' + '}');
    });
  });
});